@@ -11,6 +11,11 @@ class Common:
     APIURL          = _config.__APIURL__ + "/send/"
     APIHeaders      = _config.__APIHeaders__
 
+    ErrorEmailNotify    = ""
+
+    WebhookCallbackURL      = ""
+    WebhookCallbackFormat   = ""
+
     MessageID       = ""
     
     Reference       = ""
@@ -40,6 +45,12 @@ class Common:
 
         if "APIKey" in kwargs:
             self.APIKey = _config.__APIKey__ = kwargs.pop("APIKey")
+
+        if "WebhookCallbackURL" in kwargs:
+            self.WebhookCallbackURL = kwargs.pop("WebhookCallbackURL")
+
+        if "WebhookCallbackFormat" in kwargs:
+            self.WebhookCallbackFormat = kwargs.pop("WebhookCallbackFormat")
         
         if "MessageID" in kwargs:
             self.MessageID = kwargs.pop("MessageID")
