@@ -62,6 +62,10 @@ class Email(Common):
             "MessageData" :
             {
                 "Mode": self.SendMode,
+                "ErrorEmailNotify": self.ErrorEmailNotify,
+                "WebhookCallbackURL": self.WebhookCallbackURL,
+                "WebhookCallbackFormat": self.WebhookCallbackFormat,
+                
                 "Reference": self.Reference,
                 "SendTime": self.SendTime,
                 "TimeZone": self.Timezone,
@@ -104,6 +108,9 @@ class Email(Common):
         if not self.APIKey :
             return MessageResult(error="Empty API Key")
 
+        if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
+            return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
+
         if not self.MessagePlain and not self.MessageHTML:
             return MessageResult(error="Missing MessagePlain and MessageHTML")
 
