@@ -63,6 +63,11 @@ class Fax(Common):
             "MessageData" :
             {
                 "Mode": self.SendMode,
+                
+                "ErrorEmailNotify": self.ErrorEmailNotify,
+                "WebhookCallbackURL": self.WebhookCallbackURL,
+                "WebhookCallbackFormat": self.WebhookCallbackFormat,
+
                 "Reference": self.Reference,
                 "SendTime": self.SendTime,
                 "TimeZone": self.Timezone,
@@ -103,6 +108,9 @@ class Fax(Common):
         
         if not self.APIKey :
             return MessageResult(error="Empty APIKey")
+
+        if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
+            return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
         
         if not self.Recipients:
             return MessageResult(error="Empty Recipient(s)")
