@@ -49,6 +49,11 @@ class SMS(Common):
             "MessageData" :
             {
                 "Mode": self.SendMode,
+
+                "ErrorEmailNotify": self.ErrorEmailNotify,
+                "WebhookCallbackURL": self.WebhookCallbackURL,
+                "WebhookCallbackFormat": self.WebhookCallbackFormat,
+
                 "Reference": self.Reference,
                 "SendTime": self.SendTime,
                 "TimeZone": self.Timezone,
@@ -87,6 +92,9 @@ class SMS(Common):
         
         if not self.APIKey :
             return MessageResult(error="Empty API Key")
+
+        if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
+            return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
         
         if not self.MessageText:
             return MessageResult(error="Emtpy Message Text")
