@@ -93,6 +93,10 @@ class TTS(Common):
             {
                 "Mode": self.SendMode,
 
+                "ErrorEmailNotify": self.ErrorEmailNotify,
+                "WebhookCallbackURL": self.WebhookCallbackURL,
+                "WebhookCallbackFormat": self.WebhookCallbackFormat,
+
                 "CallerID": self.CallerID,
                 "Reference": self.Reference,
                 "SendTime": self.SendTime,
@@ -156,6 +160,9 @@ class TTS(Common):
         
         if not self.APIKey :
             return MessageResult(error="Empty APIKey")
+
+        if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
+            return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
         
         if not self.Recipients:
             return MessageResult(error="Empty Recipient(s)")
