@@ -92,6 +92,10 @@ class Voice(Common):
             "MessageData" :
             {
                 "Mode": self.SendMode,
+
+                "ErrorEmailNotify": self.ErrorEmailNotify,
+                "WebhookCallbackURL": self.WebhookCallbackURL,
+                "WebhookCallbackFormat": self.WebhookCallbackFormat,
                 
                 "Reference": self.Reference,
                 "SendTime": self.SendTime,
@@ -180,6 +184,9 @@ class Voice(Common):
         
         if not self.APIKey :
             return MessageResult(error="Empty APIKey")
+
+        if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
+            return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
         
         if not self.Recipients:
             return MessageResult(error="Empty Recipient(s)")
